@@ -1,13 +1,14 @@
 use crate::id::{
     marker::{
-        ApplicationMarker, CommandMarker, GenericMarker, GuildMarker, RoleMarker, UserMarker,
+        ApplicationMarker, ChannelMarker, CommandMarker, GenericMarker, GuildMarker, RoleMarker,
+        UserMarker,
     },
     Id,
 };
 use serde::{de::Deserializer, ser::Serializer, Deserialize, Serialize};
 use serde_repr::{Deserialize_repr, Serialize_repr};
 
-#[derive(Clone, Debug, Deserialize, Eq, PartialEq, Serialize)]
+#[derive(Clone, Debug, Deserialize, Eq, Hash, PartialEq, Serialize)]
 pub struct GuildCommandPermissions {
     pub application_id: Id<ApplicationMarker>,
     pub guild_id: Id<GuildMarker>,
@@ -15,16 +16,17 @@ pub struct GuildCommandPermissions {
     pub permissions: Vec<CommandPermissions>,
 }
 
-#[derive(Clone, Debug, Eq, PartialEq)]
+#[derive(Clone, Debug, Eq, Hash, PartialEq)]
 pub struct CommandPermissions {
     pub id: CommandPermissionsType,
     pub permission: bool,
 }
 
-#[derive(Clone, Debug, Eq, PartialEq)]
+#[derive(Clone, Debug, Eq, Hash, PartialEq)]
 pub enum CommandPermissionsType {
     Role(Id<RoleMarker>),
     User(Id<UserMarker>),
+    Channel(Id<ChannelMarker>),
 }
 
 #[derive(Deserialize, Serialize)]
@@ -40,32 +42,35 @@ struct CommandPermissionsData {
 enum CommandPermissionsDataType {
     Role = 1,
     User = 2,
+    Channel = 3,
 }
 
 impl<'de> Deserialize<'de> for CommandPermissions {
     fn deserialize<D: Deserializer<'de>>(deserializer: D) -> Result<Self, D::Error> {
         let data = CommandPermissionsData::deserialize(deserializer)?;
 
-        #[cfg(feature = "tracing")]
         let span = tracing::trace_span!("deserializing command permission");
-        #[cfg(feature = "tracing")]
         let _span_enter = span.enter();
 
         let id = match data.kind {
             CommandPermissionsDataType::Role => {
                 let id = data.id.cast();
-                #[cfg(feature = "tracing")]
                 tracing::trace!(id = %id.get(), kind = ?data.kind);
 
                 CommandPermissionsType::Role(id)
             }
             CommandPermissionsDataType::User => {
                 let id = data.id.cast();
-                #[cfg(feature = "tracing")]
                 tracing::trace!(id = %id.get(), kind = ?data.kind);
 
                 CommandPermissionsType::User(id)
             }
+            CommandPermissionsDataType::Channel => {
+                let id = data.id.cast();
+                tracing::trace!(id = %id.get(), kind = ?data.kind);
+
+                CommandPermissionsType::Channel(id)
+            }
         };
 
         Ok(Self {
@@ -81,10 +86,12 @@ impl Serialize for CommandPermissions {
             id: match self.id {
                 CommandPermissionsType::Role(role_id) => role_id.cast(),
                 CommandPermissionsType::User(user_id) => user_id.cast(),
+                CommandPermissionsType::Channel(channel_id) => channel_id.cast(),
             },
             kind: match self.id {
                 CommandPermissionsType::Role(_) => CommandPermissionsDataType::Role,
                 CommandPermissionsType::User(_) => CommandPermissionsDataType::User,
+                CommandPermissionsType::Channel(_) => CommandPermissionsDataType::Channel,
             },
             permission: self.permission,
         };
