@@ -173,38 +173,25 @@ impl<'de> Visitor<'de> for InteractionVisitor {
         let mut locale: Option<String> = None;
         let mut user: Option<Option<User>> = None;
 
-        #[cfg(feature = "tracing")]
         let span = tracing::trace_span!("deserializing interaction");
-        #[cfg(feature = "tracing")]
         let _span_enter = span.enter();
 
         loop {
-            #[cfg(feature = "tracing")]
             let span_child = tracing::trace_span!("iterating over interaction");
-            #[cfg(feature = "tracing")]
             let _span_child_enter = span_child.enter();
 
             let key = match map.next_key() {
                 Ok(Some(key)) => {
-                    #[cfg(feature = "tracing")]
                     tracing::trace!(?key, "found key");
 
                     key
                 }
                 Ok(None) => break,
-                #[cfg(feature = "tracing")]
                 Err(why) => {
                     // Encountered when we run into an unknown key.
                     map.next_value::<IgnoredAny>()?;
 
-                    tracing::trace!("ran into an unknown key: {:?}", why);
-
-                    continue;
-                }
-                #[cfg(not(feature = "tracing"))]
-                Err(_) => {
-                    // Encountered when we run into an unknown key.
-                    map.next_value::<IgnoredAny>()?;
+                    tracing::trace!("ran into an unknown key: {why:?}");
 
                     continue;
                 }
@@ -304,7 +291,6 @@ impl<'de> Visitor<'de> for InteractionVisitor {
         let token = token.ok_or_else(|| DeError::missing_field("token"))?;
         let kind = kind.ok_or_else(|| DeError::missing_field("kind"))?;
 
-        #[cfg(feature = "tracing")]
         tracing::trace!(
             %application_id,
             %id,
@@ -315,7 +301,6 @@ impl<'de> Visitor<'de> for InteractionVisitor {
 
         Ok(match kind {
             InteractionType::Ping => {
-                #[cfg(feature = "tracing")]
                 tracing::trace!("handling ping");
 
                 Self::Value::Ping(Box::new(Ping {
@@ -338,7 +323,6 @@ impl<'de> Visitor<'de> for InteractionVisitor {
                 let member = member.unwrap_or_default();
                 let user = user.unwrap_or_default();
 
-                #[cfg(feature = "tracing")]
                 tracing::trace!(%channel_id, "handling application command");
 
                 let command = Box::new(ApplicationCommand {
@@ -370,7 +354,6 @@ impl<'de> Visitor<'de> for InteractionVisitor {
                 let member = member.unwrap_or_default();
                 let user = user.unwrap_or_default();
 
-                #[cfg(feature = "tracing")]
                 tracing::trace!(%channel_id, "handling application command autocomplete");
 
                 let command = Box::new(ApplicationCommandAutocomplete {
@@ -465,11 +448,11 @@ mod tests {
                 Interaction, InteractionType,
             },
         },
-        datetime::{Timestamp, TimestampParseError},
         guild::{PartialMember, Permissions},
         id::{marker::UserMarker, Id},
         test::image_hash,
         user::User,
+        util::datetime::{Timestamp, TimestampParseError},
     };
     use serde_test::Token;
     use std::{collections::HashMap, str::FromStr};
