@@ -1,13 +1,16 @@
 use crate::{
     channel::ChannelType,
-    id::{ChannelId, GuildId},
+    id::{
+        marker::{ChannelMarker, GuildMarker},
+        Id,
+    },
 };
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Debug, Deserialize, Eq, Hash, PartialEq, Serialize)]
 pub struct ChannelMention {
-    pub guild_id: GuildId,
-    pub id: ChannelId,
+    pub guild_id: Id<GuildMarker>,
+    pub id: Id<ChannelMarker>,
     #[serde(rename = "type")]
     pub kind: ChannelType,
     pub name: String,
@@ -15,14 +18,15 @@ pub struct ChannelMention {
 
 #[cfg(test)]
 mod tests {
-    use super::{ChannelId, ChannelMention, ChannelType, GuildId};
+    use super::{ChannelMention, ChannelType};
+    use crate::id::Id;
     use serde_test::Token;
 
     #[test]
     fn test_channel_mention() {
         let value = ChannelMention {
-            guild_id: GuildId::new(1).expect("non zero"),
-            id: ChannelId::new(2).expect("non zero"),
+            guild_id: Id::new(1),
+            id: Id::new(2),
             kind: ChannelType::GuildText,
             name: "channel".to_owned(),
         };
@@ -35,10 +39,10 @@ mod tests {
                     len: 4,
                 },
                 Token::Str("guild_id"),
-                Token::NewtypeStruct { name: "GuildId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("2"),
                 Token::Str("type"),
                 Token::U8(0),
