@@ -1,10 +1,10 @@
-use crate::id::ChannelId;
+use crate::id::{marker::ChannelMarker, Id};
 use serde::{Deserialize, Serialize};
 
 /// Partial channel object that a webhook is following.
 #[derive(Clone, Debug, Deserialize, Eq, Hash, PartialEq, Serialize)]
 pub struct WebhookChannel {
-    pub id: ChannelId,
+    pub id: Id<ChannelMarker>,
     pub name: String,
 }
 
