@@ -1,11 +1,14 @@
-use crate::id::GuildId;
+use crate::{
+    id::{marker::GuildMarker, Id},
+    util::image_hash::ImageHash,
+};
 use serde::{Deserialize, Serialize};
 
 /// Partial guild object that a webhook is following.
 #[derive(Clone, Debug, Deserialize, Eq, Hash, PartialEq, Serialize)]
 pub struct WebhookGuild {
-    pub icon: Option<String>,
-    pub id: GuildId,
+    pub icon: Option<ImageHash>,
+    pub id: Id<GuildMarker>,
     pub name: String,
 }
 
