@@ -14,7 +14,6 @@ pub struct IntegrationApplication {
     pub icon: Option<ImageHash>,
     pub id: Id<ApplicationMarker>,
     pub name: String,
-    pub summary: String,
 }
 
 #[cfg(test)]
@@ -31,7 +30,6 @@ mod tests {
             icon: None,
             id: Id::new(123),
             name: "Twilight".to_string(),
-            summary: "A cool pony".to_string(),
         };
 
         serde_test::assert_tokens(
@@ -39,7 +37,7 @@ mod tests {
             &[
                 Token::Struct {
                     name: "IntegrationApplication",
-                    len: 5,
+                    len: 4,
                 },
                 Token::Str("description"),
                 Token::Str("Friendship is Magic"),
@@ -50,8 +48,6 @@ mod tests {
                 Token::Str("123"),
                 Token::Str("name"),
                 Token::Str("Twilight"),
-                Token::Str("summary"),
-                Token::Str("A cool pony"),
                 Token::StructEnd,
             ],
         );
@@ -81,7 +77,6 @@ mod tests {
             icon: None,
             id: Id::new(123),
             name: "Twilight".to_string(),
-            summary: "A cool pony".to_string(),
         };
 
         serde_test::assert_tokens(
@@ -89,7 +84,7 @@ mod tests {
             &[
                 Token::Struct {
                     name: "IntegrationApplication",
-                    len: 6,
+                    len: 5,
                 },
                 Token::Str("bot"),
                 Token::Some,
@@ -122,8 +117,6 @@ mod tests {
                 Token::Str("123"),
                 Token::Str("name"),
                 Token::Str("Twilight"),
-                Token::Str("summary"),
-                Token::Str("A cool pony"),
                 Token::StructEnd,
             ],
         );
