@@ -1,10 +1,10 @@
 use crate::{
-    datetime::Timestamp,
     guild::member::{Member, OptionalMemberDeserializer},
     id::{
         marker::{ChannelMarker, GuildMarker, UserMarker},
         Id,
     },
+    util::Timestamp,
 };
 use serde::{
     de::{Deserializer, Error as DeError, IgnoredAny, MapAccess, Visitor},
@@ -88,38 +88,25 @@ impl<'de> Visitor<'de> for VoiceStateVisitor {
         let mut user_id = None;
         let mut request_to_speak_timestamp = None;
 
-        #[cfg(feature = "tracing")]
         let span = tracing::trace_span!("deserializing voice state");
-        #[cfg(feature = "tracing")]
         let _span_enter = span.enter();
 
         loop {
-            #[cfg(feature = "tracing")]
             let span_child = tracing::trace_span!("iterating over element");
-            #[cfg(feature = "tracing")]
             let _span_child_enter = span_child.enter();
 
             let key = match map.next_key() {
                 Ok(Some(key)) => {
-                    #[cfg(feature = "tracing")]
                     tracing::trace!(?key, "found key");
 
                     key
                 }
                 Ok(None) => break,
-                #[cfg(feature = "tracing")]
                 Err(why) => {
                     // Encountered when we run into an unknown key.
                     map.next_value::<IgnoredAny>()?;
 
-                    tracing::trace!("ran into an unknown key: {:?}", why);
-
-                    continue;
-                }
-                #[cfg(not(feature = "tracing"))]
-                Err(_) => {
-                    // Encountered when we run into an unknown key.
-                    map.next_value::<IgnoredAny>()?;
+                    tracing::trace!("ran into an unknown key: {why:?}");
 
                     continue;
                 }
@@ -240,7 +227,6 @@ impl<'de> Visitor<'de> for VoiceStateVisitor {
 
         let self_stream = self_stream.unwrap_or_default();
 
-        #[cfg(feature = "tracing")]
         tracing::trace!(
             %deaf,
             %mute,
@@ -254,7 +240,6 @@ impl<'de> Visitor<'de> for VoiceStateVisitor {
         );
 
         if let (Some(guild_id), Some(member)) = (guild_id, member.as_mut()) {
-            #[cfg(feature = "tracing")]
             tracing::trace!(%guild_id, ?member, "setting member guild id");
 
             member.guild_id = guild_id;
@@ -305,9 +290,9 @@ impl<'de> Deserialize<'de> for VoiceState {
 mod tests {
     use super::{Member, VoiceState};
     use crate::{
-        datetime::{Timestamp, TimestampParseError},
         id::Id,
         user::User,
+        util::datetime::{Timestamp, TimestampParseError},
     };
     use serde_test::Token;
     use std::str::FromStr;
